export declare type TokenContext = "block" | "parens" | "brackets" | "object" | "class" | "jsxTag" | "jsxChild" | "jsxExpression" | "templateExpr" | "switchCaseCondition" | "type" | "typeParameter";
export declare type TokenType = {
    label: string;
};
export declare type Token = {
    type: TokenType;
    start: number;
    end: number;
    value: any;
    contextName?: TokenContext;
    contextStartIndex?: number;
    parentContextStartIndex?: number | null;
};
export default class TokenProcessor {
    readonly code: string;
    readonly tokens: Array<Token>;
    private resultCode;
    private tokenIndex;
    constructor(code: string, tokens: Array<Token>);
    reset(): void;
    matchesAtIndex(index: number, tagLabels: Array<string>): boolean;
    matchesNameAtIndex(index: number, name: string): boolean;
    matchesNameAtRelativeIndex(relativeIndex: number, name: string): boolean;
    matchesAtRelativeIndex(relativeIndex: number, tagLabels: Array<string>): boolean;
    matches(tagLabels: Array<string>): boolean;
    matchesName(name: string): boolean;
    /**
     * Check if this is a "real" instance of the keyword rather than an object key or property access.
     */
    matchesKeyword(name: string): boolean;
    previousWhitespace(): string;
    replaceToken(newCode: string): void;
    replaceTokenTrimmingLeftWhitespace(newCode: string): void;
    removeInitialToken(): void;
    removeToken(): void;
    copyExpectedToken(label: string): void;
    copyToken(): void;
    appendCode(code: string): void;
    currentToken(): Token;
    tokenAtRelativeIndex(relativeIndex: number): Token;
    currentIndex(): number;
    /**
     * Move to the next token. Only suitable in preprocessing steps. When
     * generating new code, you should use copyToken or removeToken.
     */
    nextToken(): void;
    expectToken(label: string): void;
    finish(): string;
    isAtEnd(): boolean;
}
