import { getTokens } from "../sucrase-babylon";
import augmentTokens from "./augmentTokens";
import TokenProcessor from "./TokenProcessor";
import RootTransformer from "./transformers/RootTransformer";
import formatTokens from "./util/formatTokens";
const DEFAULT_BABYLON_PLUGINS = ["jsx", "flow", "objectRestSpread", "classProperties"];
export function getVersion() {
    // eslint-disable-next-line
    return require("../../package.json").version;
}
export function transform(code, options = {}) {
    const transforms = options.transforms || ["jsx"];
    const tokens = getSucraseTokens(code, options);
    const tokenProcessor = new TokenProcessor(code, tokens);
    return new RootTransformer(tokenProcessor, transforms).transform();
}
/**
 * Return a string representation of the sucrase tokens, mostly useful for
 * diagnostic purposes.
 */
export function getFormattedTokens(code, options = {}) {
    const tokens = getSucraseTokens(code, options);
    return formatTokens(code, tokens);
}
function getSucraseTokens(code, options = {}) {
    const babylonPlugins = options.babylonPlugins || DEFAULT_BABYLON_PLUGINS;
    let tokens = getTokens(code, {
        tokens: true,
        sourceType: "module",
        plugins: babylonPlugins,
    } /* tslint:disable-line no-any */);
    tokens = tokens.filter((token) => token.type !== "CommentLine" && token.type !== "CommentBlock");
    augmentTokens(code, tokens);
    return tokens;
}
